@@ -2,7 +2,7 @@
 
 use strict;
 use Spreadsheet::ParseExcel;
-#~ use Data::Dumper;
+use Data::Dumper;
 
 my $parser   = Spreadsheet::ParseExcel->new();
 my $workbook = $parser->parse('TestBook.xls');
@@ -12,8 +12,14 @@ if ( !defined $workbook ) {
 }
 
 my $worksheet = $workbook->worksheet( 'Sheet1' );
-my $cell = $worksheet->get_cell( 4, 0 );
+#~ print "$worksheet\n";
+my $cell = $worksheet->get_cell( 5, 0 );
+#~ print "$cell\n";
 print	$cell->value . "\n";
+print	Dumper( $worksheet->get_merged_areas() );
+$cell = $worksheet->get_cell( 5, 1 );
+#~ print "$cell\n";
+print "Other merged area value: " . $cell->value . "\n";
 #~ print	Dumper( $cell->get_rich_text );
 
 $workbook = $parser->parse('Rich.xls');
@@ -24,5 +30,5 @@ if ( !defined $workbook ) {
 
 $worksheet = $workbook->worksheet( 'Sheet1' );
 $cell = $worksheet->get_cell( 1, 0 );
-print	$cell->value . "\n";
+print "Rich text test value: " . $cell->value . "\n";
 print	Dumper( $cell->get_rich_text );
\ No newline at end of file
